==> nextcloud-20.0.13.tgz: nextcloud/apps/dav/l10n/es.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Calendario",
    "Todos" : "Todos",
    "Personal" : "Personal",
    "{actor} created calendar {calendar}" : "{actor} creó el calendario {calendar}",
    "You created calendar {calendar}" : "Usted creó el calendario {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} eliminó el calendario {calendar}",
    "You deleted calendar {calendar}" : "Usted eliminó el calendario {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} actualizó el calendario {calendar}",
    "You updated calendar {calendar}" : "Usted actualizó el calendario {calendar}",
    "{actor} restored calendar {calendar}" : "{actor} ha restablecido el calendario {calendar}",
    "You restored calendar {calendar}" : "Has restablecido el calendario {calendar}",
    "You shared calendar {calendar} as public link" : "Has compartido el calendario {calendar} con un enlace público",
    "You removed public link for calendar {calendar}" : "Has eliminado el enlace público al calendario {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} compartió el calendario {calendar} con usted",
    "You shared calendar {calendar} with {user}" : "Usted compartió el calendario {calendar} con {usuario}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} compartió el calendario {calendar} con {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} dejó de compartir el calendario {calendar} con usted",
    "You unshared calendar {calendar} from {user}" : "Usted dejó de compartir el calendario {calendar} de {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} dejó de compartir el calendario {calendar} del usuario{user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} dejó de compartir su propio calendario {calendar}",
    "You shared calendar {calendar} with group {group}" : "Usted compartió el calendario {calendar} con el grupo {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} compartió el calendario {calendar} con el grupo {group}",
    "You unshared calendar {calendar} from group {group}" : "Usted dejó de compartir el calendario {calendar} del grupo {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} dejó de compartir el calendario {calendar} del grupo {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} creó el evento {event} en el calendario {calendar}",
    "You created event {event} in calendar {calendar}" : "Usted creó el evento {event} en el calendario {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} eliminó el evento {event} del calendario {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Usted eliminó el evento {event} del calendario {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} actualizó el evento {event} en el calendario {calendar}",
    "You updated event {event} in calendar {calendar}" : "Usted actualizó el evento {event} en el calendario {calendar}",
    "{actor} restored event {event} of calendar {calendar}" : "{actor} ha restablecido el evento {event} del calendario {calendar}",
    "You restored event {event} of calendar {calendar}" : "Has reestablecido el evento {event} del calendario {calendar}",
    "Busy" : "Ocupado",
    "{actor} created todo {todo} in list {calendar}" : "{actor} creó la tarea {todo} en la lista {calendar}",
    "You created todo {todo} in list {calendar}" : "Usted creó la tarea {todo} en la lista {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} eliminó la tarea {todo} de la lista {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Usted eliminó la tarea {tod} de la lista {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} actualizó la tarea {todo }en la lista {calendar}",
    "You updated todo {todo} in list {calendar}" : "Usted actualizó la tarea {todo} en la lista {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} completó la tarea {todo} en la lista {calendar}",
    "You solved todo {todo} in list {calendar}" : "Usted completó la tarea {todo} en la lista {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} reabrió la tarea {todo} en la lista {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Usted reabrió la tarea {todo} en la lista {calendar}",
    "Calendar, contacts and tasks" : "Calendario, contactos y tareas",
    "A <strong>calendar</strong> was modified" : "Un <strong>calendario</strong> fue modificado.",
    "A calendar <strong>event</strong> was modified" : "Un <strong>evento</strong> del calendario fue modificado.",
    "A calendar <strong>todo</strong> was modified" : "Una <strong>lista de tareas</strong> fue modificada",
    "Contact birthdays" : "Cumpleaños del contacto",
    "Death of %s" : "Muerte de %s",
    "Calendar:" : "Calendario:",
    "Date:" : "Fecha:",
    "Where:" : "Dónde:",
    "Description:" : "Descripción:",
    "Untitled event" : "Evento sin título",
    "_%n year_::_%n years_" : ["%n año","%n años"],
    "_%n month_::_%n months_" : ["%n mes","%n meses"],
    "_%n day_::_%n days_" : ["%n día","%n días"],
    "_%n hour_::_%n hours_" : ["%n hora","%n horas"],
    "_%n minute_::_%n minutes_" : ["%n minuto","%n minutos"],
    "%s (in %s)" : "%s (en %s)",
    "%s (%s ago)" : "%s (hace %s)",
    "Calendar: %s" : "Calendario: %s",
    "Date: %s" : "Fecha: %s",
    "Description: %s" : "Descripción: %s",
    "Where: %s" : "Lugar: %s",
    "%1$s via %2$s" : "%1$s vía %2$s",
    "Cancelled: %1$s" : "Cancelado: %1$s",
    "Invitation canceled" : "Invitación cancelada",
    "Re: %1$s" : "Re: %1$s",
    "Invitation updated" : "Invitación actualizada",
    "Invitation: %1$s" : "Invitación: %1$s",
    "Invitation" : "Invitación",
    "Title:" : "Título:",
    "Time:" : "Hora:",
    "Location:" : "Ubicación:",
    "Link:" : "Enlace:",
    "Organizer:" : "Organizador:",
    "Attendees:" : "Asistentes:",
    "Accept" : "Aceptar",
    "Decline" : "Rechazar",
    "More options …" : "Más opciones...",
    "More options at %s" : "Más opciones en %s",
    "Contacts" : "Contactos",
    "{actor} created address book {addressbook}" : "{actor} ha creado la libreta de direcciones {addressbook}",
    "You created address book {addressbook}" : "Has creado la libreta de direcciones {adressbook}",
    "{actor} deleted address book {addressbook}" : "{actor} ha eliminado la libreta de direcciones {addressbook}",
    "You deleted address book {addressbook}" : "Has eliminado la libreta de direcciones {addressbook}",
    "{actor} updated address book {addressbook}" : "{actor} ha actualizado la libreta de direcciones {addressbook}",
    "You updated address book {addressbook}" : "Has actualizado la libreta de direcciones {addressbook}",
    "{actor} shared address book {addressbook} with you" : "{actor} ha compartido la libreta de direcciones {addressbook} contigo",
    "You shared address book {addressbook} with {user}" : "Has compartido la libreta de direcciones {addressbook} con {user}",
    "{actor} shared address book {addressbook} with {user}" : "{actor} ha compartido la libreta de direcciones {addressbook} con {user}",
    "{actor} unshared address book {addressbook} from you" : "{actor} ha descompartido la libreta de direcciones {addressbook} contigo",
    "You unshared address book {addressbook} from {user}" : "Has descompartido la libreta de direcciones {addressbook} con {user}",
    "{actor} unshared address book {addressbook} from {user}" : "{actor} ha descompartido la libreta de direcciones {addressbook} con {user}",
    "{actor} unshared address book {addressbook} from themselves" : "{actor} ha descompartido la libreta de direcciones {addressbook} con ellos mismos",
    "You shared address book {addressbook} with group {group}" : "Has compartido la libreta de direcciones  {addressbook} con el grupo {group}",
    "{actor} shared address book {addressbook} with group {group}" : "{actor} ha compartido la libreta de direcciones {addressbook} con el grupo {group}",
    "You unshared address book {addressbook} from group {group}" : "Has descompartido la libreta de direcciones {addressbook} con el grupo {group}",
    "{actor} unshared address book {addressbook} from group {group}" : "{actor} ha descompartido la libreta de direcciones {addressbook} con el grupo {group}",
    "{actor} created contact {card} in address book {addressbook}" : "{actor} ha creado el contacto {card}  en la libreta de direcciones {addressbook}",
    "You created contact {card} in address book {addressbook}" : "Has creado un contacto {card} en la libreta de direcciones {addressbook}",
    "{actor} deleted contact {card} from address book {addressbook}" : "{actor} ha eliminado el contacto {card} de la libreta de direcciones {addressbook}",
    "You deleted contact {card} from address book {addressbook}" : "Has eliminado el contacto {card} de la libreta de direcciones {addressbook}",
    "{actor} updated contact {card} in address book {addressbook}" : "{actor} ha actualizado el contacto {card} en la libreta de direcciones {addressbook}",
    "You updated contact {card} in address book {addressbook}" : "Has actualizado el contacto {card} en la libreta de direcciones {addressbook}",
    "A <strong>contact</strong> or <strong>address book</strong> was modified" : "Se ha modificado un <strong>contacto</strong> o una  <strong>libreta de direcciones</strong> ",
    "System is in maintenance mode." : "Sistema está en modo de mantenimiento.",
    "Upgrade needed" : "Se necesita actualizar",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "Tu %s necesita configurarse para usar HTTPS en caso de usar CalDAV y CardDAV con iOS/macOS.",
    "Configures a CalDAV account" : "Configura una cuenta CalDAV",
    "Configures a CardDAV account" : "Configura una cuenta CardDAV",
    "Events" : "Eventos",
    "Tasks" : "Tareas",
    "Untitled task" : "Tarea sin título",
    "Completed on %s" : "Completado el %s",
    "Due on %s by %s" : "Finaliza el %s por %s",
    "Due on %s" : "Finaliza el %s",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "Extremo de WebDAV",
    "Calendar server" : "Servidor de calendario",
    "Send invitations to attendees" : "Enviar invitaciones a los asistentes",
    "Automatically generate a birthday calendar" : "Generar automáticamente un calendario de cumpleaños",
    "Birthday calendars will be generated by a background job." : "Los calendarios de cumpleaños se generarán mediante un trabajo en segundo plano.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Por ello, no estarán disponibles inmediatamente tras activarlos, sino que aparecerán después de cierto tiempo.",
    "Send notifications for events" : "Enviar notificaciones de los eventos",
    "Notifications are sent via background jobs, so these must occur often enough." : "Las notificaciones son enviadas a través de trabajos en segundo plano, por lo que estos deben ocurrir con la suficiente frecuencia.",
    "Enable notifications for events via push" : "Activar notificaciones push para eventos",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Instala también la {calendarappstoreopen}app de Calendario{linkclose} o {calendardocopen}conecta tu escritorio y móvil para sincronizar ↗{linkclose}.",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Por favor, asegúrate de configurar correctamente {emailopen}el servidor web{linkclose}",
    "There was an error updating your attendance status." : "Ha habido un error al actualizar tu estado de asistencia.",
    "Please contact the organizer directly." : "Por favor, contacta directamente con el organizador.",
    "Are you accepting the invitation?" : "¿Aceptas la invitación?",
    "Tentative" : "Provisional",
    "Save" : "Guardar",
    "Your attendance was updated successfully." : "Tu asistencia se ha actualizado con éxito.",
    "Calendar and tasks" : "Calendario y tareas"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-21.0.2.tgz: nextcloud/apps/dav/l10n/es.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Calendario",
    "Todos" : "Todos",
    "Personal" : "Personal",
    "{actor} created calendar {calendar}" : "{actor} creó el calendario {calendar}",
    "You created calendar {calendar}" : "Usted creó el calendario {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} eliminó el calendario {calendar}",
    "You deleted calendar {calendar}" : "Usted eliminó el calendario {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} actualizó el calendario {calendar}",
    "You updated calendar {calendar}" : "Usted actualizó el calendario {calendar}",
    "You shared calendar {calendar} as public link" : "Has compartido el calendario {calendar} con un enlace público",
    "You removed public link for calendar {calendar}" : "Has eliminado el enlace público al calendario {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} compartió el calendario {calendar} con usted",
    "You shared calendar {calendar} with {user}" : "Usted compartió el calendario {calendar} con {usuario}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} compartió el calendario {calendar} con {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} dejó de compartir el calendario {calendar} con usted",
    "You unshared calendar {calendar} from {user}" : "Usted dejó de compartir el calendario {calendar} de {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} dejó de compartir el calendario {calendar} del usuario{user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} dejó de compartir su propio calendario {calendar}",
    "You shared calendar {calendar} with group {group}" : "Usted compartió el calendario {calendar} con el grupo {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} compartió el calendario {calendar} con el grupo {group}",
    "You unshared calendar {calendar} from group {group}" : "Usted dejó de compartir el calendario {calendar} del grupo {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} dejó de compartir el calendario {calendar} del grupo {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} creó el evento {event} en el calendario {calendar}",
    "You created event {event} in calendar {calendar}" : "Usted creó el evento {event} en el calendario {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} eliminó el evento {event} del calendario {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Usted eliminó el evento {event} del calendario {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} actualizó el evento {event} en el calendario {calendar}",
    "You updated event {event} in calendar {calendar}" : "Usted actualizó el evento {event} en el calendario {calendar}",
    "Busy" : "Ocupado",
    "{actor} created todo {todo} in list {calendar}" : "{actor} creó la tarea {todo} en la lista {calendar}",
    "You created todo {todo} in list {calendar}" : "Usted creó la tarea {todo} en la lista {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} eliminó la tarea {todo} de la lista {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Usted eliminó la tarea {tod} de la lista {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} actualizó la tarea {todo }en la lista {calendar}",
    "You updated todo {todo} in list {calendar}" : "Usted actualizó la tarea {todo} en la lista {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} completó la tarea {todo} en la lista {calendar}",
    "You solved todo {todo} in list {calendar}" : "Usted completó la tarea {todo} en la lista {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} reabrió la tarea {todo} en la lista {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Usted reabrió la tarea {todo} en la lista {calendar}",
    "Calendar and tasks" : "Calendario y tareas",
    "A <strong>calendar</strong> was modified" : "Un <strong>calendario</strong> fue modificado.",
    "A calendar <strong>event</strong> was modified" : "Un <strong>evento</strong> del calendario fue modificado.",
    "A calendar <strong>todo</strong> was modified" : "Una <strong>lista de tareas</strong> fue modificada",
    "Contact birthdays" : "Cumpleaños del contacto",
    "Death of %s" : "Muerte de %s",
    "Calendar:" : "Calendario:",
    "Date:" : "Fecha:",
    "Where:" : "Dónde:",
    "Description:" : "Descripción:",
    "Untitled event" : "Evento sin título",
    "_%n year_::_%n years_" : ["%n año","%n años"],
    "_%n month_::_%n months_" : ["%n mes","%n meses"],
    "_%n day_::_%n days_" : ["%n día","%n días"],
    "_%n hour_::_%n hours_" : ["%n hora","%n horas"],
    "_%n minute_::_%n minutes_" : ["%n minuto","%n minutos"],
    "%s (in %s)" : "%s (en %s)",
    "%s (%s ago)" : "%s (hace %s)",
    "Calendar: %s" : "Calendario: %s",
    "Date: %s" : "Fecha: %s",
    "Description: %s" : "Descripción: %s",
    "Where: %s" : "Lugar: %s",
    "%1$s via %2$s" : "%1$s vía %2$s",
    "Invitation canceled" : "Invitación cancelada",
    "Invitation updated" : "Invitación actualizada",
    "Invitation" : "Invitación",
    "Title:" : "Título:",
    "Time:" : "Hora:",
    "Location:" : "Ubicación:",
    "Link:" : "Enlace:",
    "Organizer:" : "Organizador:",
    "Attendees:" : "Asistentes:",
    "Accept" : "Aceptar",
    "Decline" : "Rechazar",
    "More options …" : "Más opciones...",
    "More options at %s" : "Más opciones en %s",
    "Contacts" : "Contactos",
    "Upgrade needed" : "Se necesita actualizar",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "Tu %s necesita configurarse para usar HTTPS en caso de usar CalDAV y CardDAV con iOS/macOS.",
    "Configures a CalDAV account" : "Configura una cuenta CalDAV",
    "Configures a CardDAV account" : "Configura una cuenta CardDAV",
    "Events" : "Eventos",
    "Tasks" : "Tareas",
    "Untitled task" : "Tarea sin título",
    "Completed on %s" : "Completado el %s",
    "Due on %s by %s" : "Finaliza el %s por %s",
    "Due on %s" : "Finaliza el %s",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "Extremo de WebDAV",
    "There was an error updating your attendance status." : "Ha habido un error al actualizar tu estado de asistencia.",
    "Please contact the organizer directly." : "Por favor, contacta directamente con el organizador.",
    "Are you accepting the invitation?" : "¿Aceptas la invitación?",
    "Tentative" : "Provisional",
    "Save" : "Guardar",
    "Your attendance was updated successfully." : "Tu asistencia se ha actualizado con éxito.",
    "Calendar server" : "Servidor de calendario",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Instala también la {calendarappstoreopen}app de Calendario{linkclose} o {calendardocopen}conecta tu escritorio y móvil para sincronizar ↗{linkclose}.",
    "Send invitations to attendees" : "Enviar invitaciones a los asistentes",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Por favor, asegúrate de configurar correctamente {emailopen}el servidor web{linkclose}",
    "Automatically generate a birthday calendar" : "Generar automáticamente un calendario de cumpleaños",
    "Birthday calendars will be generated by a background job." : "Los calendarios de cumpleaños se generarán mediante un trabajo en segundo plano.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Por ello, no estarán disponibles inmediatamente tras activarlos, sino que aparecerán después de cierto tiempo.",
    "Send notifications for events" : "Enviar notificaciones de los eventos",
    "Notifications are sent via background jobs, so these must occur often enough." : "Las notificaciones son enviadas a través de trabajos en segundo plano, por lo que estos deben ocurrir con la suficiente frecuencia.",
    "Enable notifications for events via push" : "Activar notificaciones push para eventos",
    "Hello %s," : "Hola, %s:",
    "The meeting »%1$s« with %2$s was canceled." : "La reunión »%1$s« con %2$s se ha cancelado.",
    "The meeting »%1$s« with %2$s was updated." : "La reunión »%1$s« con %2$s se ha actualizado.",
    "%1$s invited you to »%2$s«" : "%1$s te ha invitado a »%2$s«",
    "When:" : "Cuándo:"
},
"nplurals=2; plural=(n != 1);");
